#include "ClientSocket.h"
#include "MapRequestPacket.h"
#include "MapChunkPacket.h"
#include "PacketTypeId.h"

#include <iostream>

#ifdef WIN32
  #include <windows.h>
  #define snooze(n) Sleep(n)
#else
  #include <unistd.h>
  #define snooze(n) usleep(n * 1000);
#endif

using namespace std;
using TEmpire::ClientSocket;

int main(int argc, char *argv[]) {

  // Create connection
  ClientSocket client;
  if(!client.Connect("localhost", 4000)) {
    return -1;
  }
  
  cout << "Connecting..." << endl;
  while(!client.IsConnected()) {
    snooze(30);
  }
  cout << "Connected!" << endl;
  
  // Request tiles (0, 0) through (7, 7)
  TEmpire::MapRequestPacket mrp;
  mrp.XStart = 0;
  mrp.XEnd = 7;
  mrp.YStart = 0;
  mrp.YEnd = 7;
  if(!client.SendPacket(&mrp)) {
    cout << "Failed to send packet!" << endl;
  }
    
  // Receive packets
  while(true) {
    TEmpire::Packet *packet = client.ReceivePacket();
    
    if(packet == NULL) {
      snooze(30);
      continue;
    }
  
    cout << "Packet received!" << endl;
    
    switch(packet->GetType()) {
      case TEmpire::PCID_MAPCHUNK:
        cout << "Got MapChunkPacket" << endl;
        break;
    }
    
    delete packet;
  }
  
  return 0;
}
